###################################################
### preliminaries
###################################################
set.seed(1071)
library(vcd)
data(Titanic)
data(HairEyeColor)
data(PreSex)
data(Arthritis)
art <- xtabs(~Treatment + Improved, data = Arthritis)


###################################################
### Arthritis
###################################################
mosaic(art, gp = shading_max, split_vertical = TRUE)


###################################################
### UCBAdmissions
###################################################
cotabplot(UCBAdmissions, panel = cotab_coindep, shade = TRUE, legend = FALSE, 
          type = "assoc")


###################################################
### PreSex
###################################################
presextest <- coindep_test(PreSex, margin = c(1,4), 
                           indepfun = function(x) sum(x^2), n = 5000)
mosaic(PreSex, condvars = c(1, 4), shade = TRUE, 
       gp_args = list(p.value = presextest$p.value))


###################################################
### Titanic
###################################################
doubledecker(Survived ~ ., data = Titanic, labeling_args = 
             list(set_varnames = c(Sex = "Gender")))


###################################################
### structable
###################################################
(HEC <- structable(Eye ~ Sex + Hair, data = HairEyeColor))


###################################################
### Observed
###################################################
mosaic(HEC)


###################################################
### Observed2
###################################################
mosaic(~ Sex + Eye + Hair, data = HairEyeColor)


###################################################
### Expected
###################################################
mosaic(HEC, type = "expected")


###################################################
### sieve
###################################################
sieve(~ Sex + Eye + Hair, data = HEC, spacing = spacing_dimequal(c(2,0,0)))


###################################################
### Residuals
###################################################
assoc(HEC, compress = FALSE)


###################################################
### split1
###################################################
mosaic(HEC, split_vertical = c(TRUE, FALSE, TRUE), 
labeling_args = list(abbreviate = c(Eye = 3)))


###################################################
### split2
###################################################
mosaic(HEC, direction = c("v","h","v"))


###################################################
### doubledecker1
###################################################
doubledecker(Titanic)


###################################################
### doubledecker2
###################################################
doubledecker(Survived ~ Class + Sex + Age, data = Titanic)


###################################################
### subsetting
###################################################
(STD <- structable(~ Sex + Class + Age, data = Titanic[,,2:1,]))
STD["Male",]
STD["Male", c("1st","2nd","3rd")]


###################################################
### conditioning
###################################################
STD[["Male",]]
STD[[c("Male", "Adult"),]]
STD[["Male","1st"]]


###################################################
### Variables
###################################################
pushViewport(viewport(layout = grid.layout(ncol = 2)))
pushViewport(viewport(layout.pos.col = 1))
mosaic(STD[["Male"]], margins = c(left = 2.5, top = 2.5, 0), sub = "Male", newpage = FALSE)
popViewport()
pushViewport(viewport(layout.pos.col = 2))
mosaic(STD[["Female"]], margins = c(top = 2.5, 0), sub = "Female", newpage = FALSE)
popViewport(2)


###################################################
### cotabplot
###################################################
cotabplot(~ Class + Age | Sex, data = STD, split_vertical = TRUE)


###################################################
### Conditioning1
###################################################
mosaic(STD, condvars = "Sex", split_vertical = c(TRUE, TRUE, FALSE))


###################################################
### Conditioning2
###################################################
mosaic(~ Class + Age | Sex, data = STD, split_vertical = c(TRUE, TRUE, FALSE))


###################################################
### pairs
###################################################
pairs(STD, highlighting = 2, diag_panel = pairs_diagonal_mosaic, 
      diag_panel_args = list(fill = grey.colors))


###################################################
### viewportnames
###################################################
mosaic(~ Hair + Eye, data = HEC, pop = FALSE)

seekViewport("cell:Hair=Blond")
grid.rect(gp = gpar(col = "red", lwd = 4))

seekViewport("cell:Hair=Blond,Eye=Blue")
grid.circle(r = 0.2, gp = gpar(fill = "cyan"))


###################################################
### changeplot
###################################################
assoc(Eye ~ Hair, data = HEC, pop = FALSE)
getNames()[1:6]
grid.edit("rect:Hair=Blond,Eye=Blue", gp = gpar(fill = "red"))


###################################################
### ucb
###################################################
(ucb <- margin.table(UCBAdmissions, 1:2))

(fill_colors <- matrix(c("dark cyan","gray","gray","dark magenta"), ncol = 2))

mosaic(ucb, gp = gpar(fill = fill_colors, col = 0))


###################################################
### recycling
###################################################
mosaic(Titanic, gp = gpar(fill = c("gray","dark magenta")),
                spacing = spacing_highlighting,
                labeling_args = list(abbreviate = c(Age = 3), rep = c(Survived = FALSE))
      )


###################################################
### shading1
###################################################
expected <- independence_table(ucb)
(x <- (ucb - expected)  / sqrt(expected))
(shading1_obj <- ifelse(x > 0, "royalblue4", "mediumorchid4"))
mosaic(ucb, gp = gpar(fill = shading1_obj))


###################################################
### shading2
###################################################
shading2_fun <- function(x) gpar(fill = ifelse(x > 0, "royalblue4", "mediumorchid4"))


###################################################
### shading3
###################################################
mosaic(ucb, gp = shading2_fun)


###################################################
### shading3
###################################################
shading3a_fun <- function(col = c("royalblue4", "mediumorchid4")) {
  col <- rep(col, length.out = 2)
  function(x) gpar(fill = ifelse(x > 0, col[1], col[2]))  
}


###################################################
### shading4
###################################################
mosaic(ucb, gp = shading3a_fun(c("royalblue4","mediumorchid4")))


###################################################
### shading4
###################################################
shading3b_fun <- function(observed = NULL, residuals = NULL, expected = NULL, 
    df = NULL, col = c("royalblue4", "mediumorchid4")) {
  col <- rep(col, length.out = 2)
  function(x) gpar(fill = ifelse(x > 0, col[1], col[2]))  
}
class(shading3b_fun) <- "grapcon_generator"


###################################################
### shading5
###################################################
mosaic(ucb, gp = shading3b_fun, gp_args = list(col = c("red","blue")))


###################################################
### haireye1
###################################################
haireye <- margin.table(HairEyeColor, 1:2)
mosaic(haireye, gp = shading_hsv)


###################################################
### haireye2
###################################################
mosaic(haireye, gp = shading_hcl)


###################################################
### haireye3
###################################################
mosaic(haireye, gp = shading_hcl, gp_args = list(h = c(130, 43), c = 100, l = c(90, 70)))


###################################################
### haireyefig2
###################################################
mosaic(haireye, gp = shading_hcl, margin = c(bottom = 1), keep_aspect_ratio = FALSE)


###################################################
### haireyefig3
###################################################
mosaic(haireye, gp = shading_hcl, margin = c(bottom = 1), gp_args = list(h = c(130, 43), c = 100, l = c(90, 70)), keep_aspect_ratio = FALSE)


###################################################
### interpolate
###################################################
mosaic(haireye, shade = TRUE, gp_args = list(interpolate = 1:4))


###################################################
### continuous1
###################################################
ipol <- function(x) pmin(x/4, 1)


###################################################
### continuous2
###################################################
mosaic(haireye, shade = TRUE, gp_args = list(interpolate = ipol),
labeling_args = list(abbreviate = c(Sex = TRUE)))


###################################################
### bundesliga
###################################################
BL <- xtabs(~ HomeGoals + AwayGoals, data = Bundesliga, subset = Year == 1995)
mosaic(BL, shade = TRUE)


###################################################
### friendly
###################################################
mosaic(BL, gp = shading_Friendly, legend = legend_fixed, zero_size = 0)


###################################################
### arthritis
###################################################
set.seed(4711)
mosaic(~ Treatment + Improved, data = Arthritis, subset = Sex == "Female",
       gp = shading_max)


###################################################
### default
###################################################
mosaic(Titanic)


###################################################
### clipping
###################################################
mosaic(Titanic, labeling_args = list(clip = c(Survived = TRUE, Age = TRUE)))


###################################################
### abbreviating
###################################################
mosaic(Titanic, labeling_args = list(abbreviate = c(Survived = TRUE, Age = 3)))


###################################################
### rotate
###################################################
mosaic(Titanic, labeling_args = list(rot_labels = c(bottom = 90, right = 0), 
offset_varnames = c(right = 1), offset_labels = c(right = 0.3)), 
margins = c(right = 4, bottom = 3))


###################################################
### repeat
###################################################
mosaic(Titanic, labeling_args = list(rep = c(Survived = FALSE, Age = FALSE)))


###################################################
### left
###################################################
mosaic(Titanic, labeling_args = list(pos_varnames = "left", pos_labels = "left", 
       just_labels = "left", rep = FALSE))


###################################################
### left2
###################################################
mosaic(Titanic, labeling = labeling_left)


###################################################
### margins
###################################################
mosaic(Titanic, labeling_args = list(tl_labels = FALSE, tl_varnames = TRUE, abbreviate = c(Survived = 1, Age = 3)))


###################################################
### boxes
###################################################
mosaic(Titanic, labeling_args = list(tl_labels = FALSE, tl_varnames = TRUE, 
       boxes = TRUE, clip = TRUE))


###################################################
### boxes2
###################################################
mosaic(Titanic, labeling = labeling_cboxed)


###################################################
### labbl
###################################################
mosaic(Titanic, labeling_args = list(tl_labels = TRUE, boxes = TRUE,
       clip = c(Survived = FALSE, Age = FALSE, TRUE), abbreviate = c(Age = 4),
       labbl_varnames = TRUE), margins = c(left = 4, right = 1, 3))


###################################################
### labbl2
###################################################
mosaic(Titanic, labeling = labeling_lboxed, margins = c(right = 4, left = 1, 3))


###################################################
### cell
###################################################
mosaic(~ MaritalStatus + Gender, data = PreSex, labeling = labeling_cells)


###################################################
### cell2
###################################################
mosaic(~ PremaritalSex + ExtramaritalSex, data = PreSex, 
labeling = labeling_cells(abbreviate_labels = TRUE, abbreviate_varnames = TRUE, clip = FALSE))


###################################################
### conditional
###################################################
mosaic(~ PremaritalSex + ExtramaritalSex | MaritalStatus + Gender, data = PreSex, labeling = labeling_conditional(abbreviate_varnames = TRUE, abbreviate_labels = TRUE, clip = FALSE, gp_text = gpar(col = "red")))


###################################################
### text
###################################################
mosaic(Titanic, labeling_args = list(abbreviate = c(Survived = 1, Age = 4)), pop = FALSE)

tab <- ifelse(Titanic < 6, NA, Titanic)
labeling_cells(text = tab, clip = FALSE)(Titanic)


###################################################
### list
###################################################
mosaic(Titanic, labeling = labeling_list, margins = c(bottom = 5))


###################################################
### listfig
###################################################
mosaic(Titanic, labeling = labeling_list, margins = c(bottom = 5), keep = TRUE)


###################################################
### artspine
###################################################
(art <- structable(~Treatment + Improved, data = Arthritis, split_vertical = TRUE))
(my_spacing <- list(unit(0.5, "lines"), unit(c(0, 0), "lines")))
my_colors <- c("lightgray", "lightgray", "black")
mosaic(art, spacing = my_spacing, gp = gpar(fill = my_colors, col = my_colors))


###################################################
### artspine
###################################################
mosaic(Improved ~ Treatment, data = Arthritis, split_vertical = TRUE)


###################################################
### space1
###################################################
mosaic(art, spacing = spacing_equal(unit(2, "lines")))


###################################################
### space2
###################################################
mosaic(art, spacing = spacing_dimequal(unit(1:2, "lines")))


###################################################
### space3
###################################################
mosaic(art, spacing = spacing_increase(start = unit(0.5, "lines"), rate = 1.5))


###################################################
### spine4
###################################################
mosaic(art, spacing = spacing_highlighting, gp = my_colors)


###################################################
### oc1
###################################################
tab <- xtabs(Freq ~ stage + operation + xray + survival, data = OvaryCancer)


###################################################
### oc2
###################################################
structable(survival ~ ., data = tab)


###################################################
### oc3
###################################################
dpa <- list(var_offset = 1.2, rot = -30, just_leveltext= "left")
pairs(tab, diag_panel_args = dpa)


###################################################
### oc4
###################################################
doubledecker(survival ~ stage + operation + xray, data = tab)


###################################################
### oc6
###################################################
split <- c(TRUE, TRUE, TRUE, FALSE)
mosaic(tab, expected = ~ survival + operation * xray * stage, split_vertical = split)


###################################################
### oc7
###################################################
mosaic(tab, expected = ~ (survival + operation * xray) * stage, split_vertical = split)
